@@ -19,17 +19,17 @@
 pub mod account;
 pub use account::*;
 
-pub mod account_address;
-pub use account_address::*;
-
 pub mod account_format;
 pub use account_format::*;
 
-pub mod account_private_key;
-pub use account_private_key::*;
+pub mod address;
+pub use address::*;
 
-pub mod account_view_key;
-pub use account_view_key::*;
+pub mod private_key;
+pub use private_key::*;
+
+pub mod view_key;
+pub use view_key::*;
 
 #[cfg(test)]
 pub mod tests;
