@@ -16,49 +16,59 @@
 
 use crate::{
     testnet1::{LocalData, NoopCircuit, PrivateProgramInput, ProgramLocalData, Testnet1Components},
-    traits::{ProgramScheme, RecordScheme},
-    DPCError,
+    DPCComponents,
+    ProgramError,
+    ProgramScheme,
+    RecordScheme,
 };
-use snarkvm_algorithms::traits::{CommitmentScheme, SNARK};
+use snarkvm_algorithms::{CommitmentScheme, CRH, SNARK};
 use snarkvm_utilities::{to_bytes, ToBytes};
 
 use rand::Rng;
-use std::marker::PhantomData;
 
 #[derive(Derivative)]
-#[derivative(
-    Clone(bound = "C: Testnet1Components, S: SNARK"),
-    Debug(bound = "C: Testnet1Components, S: SNARK")
-)]
-pub struct NoopProgram<C: Testnet1Components, S: SNARK> {
+#[derivative(Clone(bound = "C: Testnet1Components"), Debug(bound = "C: Testnet1Components"))]
+pub struct NoopProgram<C: Testnet1Components> {
     #[derivative(Default(value = "vec![0u8; 48]"))]
     id: Vec<u8>,
     #[derivative(Debug = "ignore")]
-    proving_key: S::ProvingKey,
+    proving_key: <<C as Testnet1Components>::NoopProgramSNARK as SNARK>::ProvingKey,
     #[derivative(Debug = "ignore")]
-    verifying_key: S::VerifyingKey,
-    #[derivative(Debug = "ignore")]
-    _components: PhantomData<C>,
+    verifying_key: <<C as Testnet1Components>::NoopProgramSNARK as SNARK>::VerifyingKey,
 }
 
-impl<C: Testnet1Components, S: SNARK> ProgramScheme for NoopProgram<C, S>
-where
-    S: SNARK<AllocatedCircuit = NoopCircuit<C>, VerifierInput = ProgramLocalData<C>>,
-{
-    type Id = Vec<u8>;
+impl<C: Testnet1Components> ProgramScheme for NoopProgram<C> {
+    type ID = Vec<u8>;
     type LocalData = LocalData<C>;
     type PrivateWitness = PrivateProgramInput;
-    type ProvingKey = S::ProvingKey;
+    type ProgramIDCRH = C::ProgramVerificationKeyCRH;
+    type ProofSystem = <C as Testnet1Components>::NoopProgramSNARK;
+    type ProvingKey = <Self::ProofSystem as SNARK>::ProvingKey;
     type PublicInput = ();
-    type VerifyingKey = S::VerifyingKey;
+    type VerifyingKey = <Self::ProofSystem as SNARK>::VerifyingKey;
 
-    fn new(program_id: Self::Id, proving_key: Self::ProvingKey, verifying_key: Self::VerifyingKey) -> Self {
-        Self {
+    /// Initializes a new instance of a program.
+    fn new(
+        program_id_crh_parameters: &Self::ProgramIDCRH,
+        proving_key: Self::ProvingKey,
+        verifying_key: Self::VerifyingKey,
+    ) -> Result<Self, ProgramError> {
+        // Compute the program ID.
+        let program_id = to_bytes![<C as DPCComponents>::ProgramVerificationKeyCRH::hash(
+            program_id_crh_parameters,
+            &to_bytes![verifying_key]?
+        )?]?;
+
+        Ok(Self {
             id: program_id,
             proving_key,
             verifying_key,
-            _components: PhantomData,
-        }
+        })
+    }
+
+    /// Returns the program ID.
+    fn id(&self) -> Self::ID {
+        self.id.clone()
     }
 
     fn execute<R: Rng>(
@@ -66,31 +76,26 @@ where
         local_data: &Self::LocalData,
         position: u8,
         rng: &mut R,
-    ) -> Result<Self::PrivateWitness, DPCError> {
-        let num_records = local_data.old_records.len() + local_data.new_records.len();
-        assert!((position as usize) < num_records);
+    ) -> Result<Self::PrivateWitness, ProgramError> {
+        assert!((position as usize) < (local_data.old_records.len() + local_data.new_records.len()));
 
-        let record = if (position as usize) < local_data.old_records.len() {
-            &local_data.old_records[position as usize]
-        } else {
-            &local_data.new_records[position as usize - local_data.old_records.len()]
+        let record = match (position as usize) < local_data.old_records.len() {
+            true => &local_data.old_records[position as usize],
+            false => &local_data.new_records[position as usize - local_data.old_records.len()],
         };
 
-        if (position as usize) < C::NUM_INPUT_RECORDS {
-            assert_eq!(self.id, record.death_program_id());
-        } else {
-            assert_eq!(self.id, record.birth_program_id());
-        }
+        match (position as usize) < C::NUM_INPUT_RECORDS {
+            true => assert_eq!(self.id, record.death_program_id()),
+            false => assert_eq!(self.id, record.birth_program_id()),
+        };
 
         let local_data_root = local_data.local_data_merkle_tree.root();
 
         let circuit = NoopCircuit::<C>::new(&local_data.system_parameters, &local_data_root, position);
 
-        let proof = S::prove(&self.proving_key, &circuit, rng)?;
+        let proof = <Self::ProofSystem as SNARK>::prove(&self.proving_key, &circuit, rng)?;
 
         {
-            let program_snark_pvk: <S as SNARK>::PreparedVerifyingKey = self.verifying_key.clone().into();
-
             let program_pub_input: ProgramLocalData<C> = ProgramLocalData {
                 local_data_commitment_parameters: local_data
                     .system_parameters
@@ -100,7 +105,11 @@ where
                 local_data_root,
                 position,
             };
-            assert!(S::verify(&program_snark_pvk, &program_pub_input, &proof)?);
+            assert!(<Self::ProofSystem as SNARK>::verify(
+                &self.verifying_key.clone().into(),
+                &program_pub_input,
+                &proof
+            )?);
         }
 
         Ok(Self::PrivateWitness {
