@@ -26,7 +26,7 @@ use snarkvm_algorithms::{
     merkle_tree::{MerklePath, MerkleTreeDigest},
     prelude::*,
 };
-use snarkvm_curves::traits::{Group, MontgomeryModelParameters, ProjectiveCurve, TEModelParameters};
+use snarkvm_curves::traits::{Group, MontgomeryParameters, ProjectiveCurve, TwistedEdwardsParameters};
 use snarkvm_fields::ToConstraintField;
 use snarkvm_gadgets::{
     bits::Boolean,
@@ -79,7 +79,7 @@ pub trait Testnet2Components: DPCComponents {
     /// Group and Model Parameters for record encryption
     type EncryptionGroup: Group + ProjectiveCurve;
     type EncryptionGroupGadget: CompressedGroupGadget<Self::EncryptionGroup, Self::InnerScalarField>;
-    type EncryptionModelParameters: MontgomeryModelParameters + TEModelParameters;
+    type EncryptionModelParameters: MontgomeryParameters + TwistedEdwardsParameters;
 
     /// SNARK for non-proof-verification checks
     type InnerSNARK: SNARK<
@@ -308,14 +308,11 @@ where
         end_timer!(snark_setup_time);
         end_timer!(setup_time);
 
-        let inner_snark_parameters = (Some(inner_snark_parameters.0), inner_snark_parameters.1);
-        let outer_snark_parameters = (Some(outer_snark_parameters.0), outer_snark_parameters.1);
-
         Ok(PublicParameters {
             system_parameters,
             noop_program_snark_parameters,
-            inner_snark_parameters,
-            outer_snark_parameters,
+            inner_snark_parameters: (Some(inner_snark_parameters.0), inner_snark_parameters.1),
+            outer_snark_parameters: (Some(outer_snark_parameters.0), outer_snark_parameters.1),
         })
     }
 
@@ -346,13 +343,13 @@ where
         assert_eq!(C::NUM_INPUT_RECORDS, old_records.len());
         assert_eq!(C::NUM_OUTPUT_RECORDS, new_records.len());
 
+        let mut value_balance = AleoAmount::ZERO;
+
         let mut old_serial_numbers = Vec::with_capacity(C::NUM_INPUT_RECORDS);
         let mut old_randomizers = Vec::with_capacity(C::NUM_INPUT_RECORDS);
         let mut joint_serial_numbers = Vec::new();
         let mut old_death_program_ids = Vec::with_capacity(C::NUM_INPUT_RECORDS);
 
-        let mut value_balance = AleoAmount::ZERO;
-
         // Compute the ledger membership witness and serial number from the old records.
         for (i, record) in old_records.iter().enumerate().take(C::NUM_INPUT_RECORDS) {
             let input_record_time = start_timer!(|| format!("Process input record {}", i));
@@ -397,15 +394,18 @@ where
             end_timer!(output_record_time);
         }
 
-        // TODO (raychu86) Add index and program register inputs + outputs to local data commitment leaves
+        // TODO (raychu86): Add index and program register inputs + outputs to local data commitment leaves
         let local_data_merkle_tree_timer = start_timer!(|| "Compute local data merkle tree");
 
         let mut local_data_commitment_randomizers = Vec::with_capacity(C::NUM_INPUT_RECORDS);
-
         let mut old_record_commitments = Vec::with_capacity(C::NUM_INPUT_RECORDS);
         for i in 0..C::NUM_INPUT_RECORDS {
-            let record = &old_records[i];
-            let input_bytes = to_bytes![old_serial_numbers[i], record.commitment(), memorandum, C::NETWORK_ID]?;
+            let input_bytes = to_bytes![
+                old_serial_numbers[i],
+                &old_records[i].commitment(),
+                memorandum,
+                C::NETWORK_ID
+            ]?;
 
             let commitment_randomness = <C::LocalDataCommitment as CommitmentScheme>::Randomness::rand(rng);
             let commitment = C::LocalDataCommitment::commit(
@@ -449,7 +449,6 @@ where
             for id in old_death_program_ids {
                 input.extend_from_slice(&id);
             }
-
             for id in new_birth_program_ids {
                 input.extend_from_slice(&id);
             }
@@ -463,22 +462,18 @@ where
         };
         end_timer!(program_comm_timer);
 
-        // Encrypt the new records
+        // Encrypt the new records and construct the ciphertext hashes
 
         let mut new_records_encryption_randomness = Vec::with_capacity(C::NUM_OUTPUT_RECORDS);
+        let mut new_encrypted_record_hashes = Vec::with_capacity(C::NUM_OUTPUT_RECORDS);
         let mut new_encrypted_records = Vec::with_capacity(C::NUM_OUTPUT_RECORDS);
 
         for record in &new_records {
             let (encrypted_record, record_encryption_randomness) = EncryptedRecord::encrypt(&parameters, record, rng)?;
 
             new_records_encryption_randomness.push(record_encryption_randomness);
-            new_encrypted_records.push(encrypted_record);
-        }
-
-        // Construct the ciphertext hashes
-        let mut new_encrypted_record_hashes = Vec::with_capacity(C::NUM_OUTPUT_RECORDS);
-        for encrypted_record in &new_encrypted_records {
             new_encrypted_record_hashes.push(encrypted_record.to_hash(&parameters)?);
+            new_encrypted_records.push(encrypted_record);
         }
 
         Ok(TransactionKernel {
@@ -564,7 +559,7 @@ where
         }
 
         // Generate Schnorr signature on transaction data
-        // TODO (raychu86) Remove ledger_digest from signature and move the schnorr signing into `execute_offline_phase`
+        // TODO (raychu86): Remove ledger_digest from signature and move the schnorr signing into `execute_offline_phase`
         let signature_time = start_timer!(|| "Sign and randomize transaction contents");
 
         let signature_message = to_bytes![
@@ -580,18 +575,19 @@ where
 
         let mut signatures = Vec::with_capacity(C::NUM_INPUT_RECORDS);
         for i in 0..C::NUM_INPUT_RECORDS {
-            let sk_sig = &old_private_keys[i].sk_sig;
-            let randomizer = &old_randomizers[i];
-
             // Sign the transaction data
-            let account_signature =
-                C::AccountSignature::sign(&system_parameters.account_signature, sk_sig, &signature_message, rng)?;
+            let account_signature = C::AccountSignature::sign(
+                &system_parameters.account_signature,
+                &old_private_keys[i].sk_sig,
+                &signature_message,
+                rng,
+            )?;
 
             // Randomize the signature
             let randomized_signature = C::AccountSignature::randomize_signature(
                 &system_parameters.account_signature,
                 &account_signature,
-                randomizer,
+                &old_randomizers[i],
             )?;
 
             signatures.push(randomized_signature);
