@@ -35,8 +35,8 @@ pub use program::*;
 pub mod record;
 pub use record::*;
 
-pub mod record_encoding;
-pub use record_encoding::*;
+pub mod encoded;
+pub use encoded::*;
 
 pub mod storage;
 pub use storage::*;
